@@ -13,41 +13,33 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /**
  * SECTION:gstpbutilsmissingplugins
+ * @title: Missing plugins
  * @short_description: Create, recognise and parse missing-plugins messages
  *
- * <refsect2>
- * <para>
  * Functions to create, recognise and parse missing-plugins messages for
  * applications and elements.
- * </para>
- * <para>
+ *
  * Missing-plugin messages are posted on the bus by elements like decodebin
  * or playbin if they can't find an appropriate source element or decoder
  * element. The application can use these messages for two things:
- * <itemizedlist>
- *   <listitem><para>
- *     concise error/problem reporting to the user mentioning what exactly
+ *
+ *   * concise error/problem reporting to the user mentioning what exactly
  *     is missing, see gst_missing_plugin_message_get_description()
- *   </para></listitem>
- *   <listitem><para>
- *     initiate installation of missing plugins, see
+ *
+ *   * initiate installation of missing plugins, see
  *     gst_missing_plugin_message_get_installer_detail() and
  *     gst_install_plugins_async()
- *   </para></listitem>
- * </itemizedlist>
- * </para>
- * <para>
+ *
  * Applications may also create missing-plugin messages themselves to install
  * required elements that are missing, using the install mechanism mentioned
  * above.
- * </para>
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -126,6 +118,7 @@ copy_and_clean_caps (const GstCaps * caps)
    * where template caps usually have the standard MIN - MAX range as value) */
   s = gst_caps_get_structure (ret, 0);
   gst_structure_remove_field (s, "codec_data");
+  gst_structure_remove_field (s, "streamheader");
   gst_structure_remove_field (s, "palette_data");
   gst_structure_remove_field (s, "pixel-aspect-ratio");
   gst_structure_remove_field (s, "framerate");
@@ -141,20 +134,23 @@ copy_and_clean_caps (const GstCaps * caps)
   gst_structure_remove_field (s, "height");
   gst_structure_remove_field (s, "channels");
   gst_structure_remove_field (s, "rate");
+  /* parsed, framed, stream-format and alignment are going to be handled by
+   * parsers and not relevant for decoders/encoders usually */
+  gst_structure_remove_field (s, "parsed");
+  gst_structure_remove_field (s, "framed");
+  gst_structure_remove_field (s, "stream-format");
+  gst_structure_remove_field (s, "alignment");
   /* rtp fields */
   gst_structure_remove_field (s, "config");
   gst_structure_remove_field (s, "clock-rate");
-  gst_structure_remove_field (s, "clock-base");
+  gst_structure_remove_field (s, "timestamp-offset");
   gst_structure_remove_field (s, "maxps");
-  gst_structure_remove_field (s, "seqnum-base");
+  gst_structure_remove_field (s, "seqnum-offset");
   gst_structure_remove_field (s, "npt-start");
   gst_structure_remove_field (s, "npt-stop");
   gst_structure_remove_field (s, "play-speed");
   gst_structure_remove_field (s, "play-scale");
   gst_structure_remove_field (s, "dynamic_range");
-  /* mpegaudioversion is a duplicate for mpegversion
-   * https://bugzilla.redhat.com/show_bug.cgi?id=680809 */
-  gst_structure_remove_field (s, "mpegaudioversion");
 
   return ret;
 }
@@ -393,7 +389,7 @@ missing_structure_get_caps_detail (const GstStructure * s, GstCaps ** p_caps)
  * Returns an opaque string containing all the details about the missing
  * element to be passed to an external installer called via
  * gst_install_plugins_async() or gst_install_plugins_sync().
- * 
+ *
  * This function is mainly for applications that call external plugin
  * installation mechanisms using one of the two above-mentioned functions.
  *
@@ -409,23 +405,25 @@ gst_missing_plugin_message_get_installer_detail (GstMessage * msg)
   GString *str = NULL;
   gchar *detail = NULL;
   gchar *desc;
+  const GstStructure *structure;
 
   g_return_val_if_fail (gst_is_missing_plugin_message (msg), NULL);
 
-  GST_LOG ("Parsing missing-plugin message: %" GST_PTR_FORMAT, msg->structure);
+  structure = gst_message_get_structure (msg);
+  GST_LOG ("Parsing missing-plugin message: %" GST_PTR_FORMAT, structure);
 
-  missing_type = missing_structure_get_type (msg->structure);
+  missing_type = missing_structure_get_type (structure);
   if (missing_type == GST_MISSING_TYPE_UNKNOWN) {
     GST_WARNING ("couldn't parse 'type' field");
     goto error;
   }
 
-  type = gst_structure_get_string (msg->structure, "type");
+  type = gst_structure_get_string (structure, "type");
   g_assert (type != NULL);      /* validity already checked above */
 
   /* FIXME: use gst_installer_detail_new() here too */
   str = g_string_new (GST_DETAIL_STRING_MARKER "|");
-  g_string_append_printf (str, "%u.%u|", GST_VERSION_MAJOR, GST_VERSION_MINOR);
+  g_string_append_printf (str, "%s|", GST_API_VERSION);
 
   progname = (const gchar *) g_get_prgname ();
   if (progname) {
@@ -447,14 +445,14 @@ gst_missing_plugin_message_get_installer_detail (GstMessage * msg)
     case GST_MISSING_TYPE_URISOURCE:
     case GST_MISSING_TYPE_URISINK:
     case GST_MISSING_TYPE_ELEMENT:
-      if (!missing_structure_get_string_detail (msg->structure, &detail))
+      if (!missing_structure_get_string_detail (structure, &detail))
         goto error;
       break;
     case GST_MISSING_TYPE_DECODER:
     case GST_MISSING_TYPE_ENCODER:{
       GstCaps *caps = NULL;
 
-      if (!missing_structure_get_caps_detail (msg->structure, &caps))
+      if (!missing_structure_get_caps_detail (structure, &caps))
         goto error;
 
       detail = gst_caps_to_string (caps);
@@ -501,19 +499,21 @@ gst_missing_plugin_message_get_description (GstMessage * msg)
   GstMissingType missing_type;
   const gchar *desc;
   gchar *ret = NULL;
+  const GstStructure *structure;
 
   g_return_val_if_fail (gst_is_missing_plugin_message (msg), NULL);
 
-  GST_LOG ("Parsing missing-plugin message: %" GST_PTR_FORMAT, msg->structure);
+  structure = gst_message_get_structure (msg);
+  GST_LOG ("Parsing missing-plugin message: %" GST_PTR_FORMAT, structure);
 
-  desc = gst_structure_get_string (msg->structure, "name");
+  desc = gst_structure_get_string (structure, "name");
   if (desc != NULL && *desc != '\0') {
     ret = g_strdup (desc);
     goto done;
   }
 
   /* fallback #1 */
-  missing_type = missing_structure_get_type (msg->structure);
+  missing_type = missing_structure_get_type (structure);
 
   switch (missing_type) {
     case GST_MISSING_TYPE_URISOURCE:
@@ -521,13 +521,13 @@ gst_missing_plugin_message_get_description (GstMessage * msg)
     case GST_MISSING_TYPE_ELEMENT:{
       gchar *detail = NULL;
 
-      if (missing_structure_get_string_detail (msg->structure, &detail)) {
+      if (missing_structure_get_string_detail (structure, &detail)) {
         if (missing_type == GST_MISSING_TYPE_URISOURCE)
           ret = gst_pb_utils_get_source_description (detail);
         else if (missing_type == GST_MISSING_TYPE_URISINK)
           ret = gst_pb_utils_get_sink_description (detail);
         else
-          ret = gst_pb_utils_get_sink_description (detail);
+          ret = gst_pb_utils_get_element_description (detail);
         g_free (detail);
       }
       break;
@@ -536,7 +536,7 @@ gst_missing_plugin_message_get_description (GstMessage * msg)
     case GST_MISSING_TYPE_ENCODER:{
       GstCaps *caps = NULL;
 
-      if (missing_structure_get_caps_detail (msg->structure, &caps)) {
+      if (missing_structure_get_caps_detail (structure, &caps)) {
         if (missing_type == GST_MISSING_TYPE_DECODER)
           ret = gst_pb_utils_get_decoder_description (caps);
         else
@@ -594,13 +594,16 @@ done:
 gboolean
 gst_is_missing_plugin_message (GstMessage * msg)
 {
+  const GstStructure *structure;
+
   g_return_val_if_fail (msg != NULL, FALSE);
   g_return_val_if_fail (GST_IS_MESSAGE (msg), FALSE);
 
-  if (GST_MESSAGE_TYPE (msg) != GST_MESSAGE_ELEMENT || msg->structure == NULL)
+  structure = gst_message_get_structure (msg);
+  if (GST_MESSAGE_TYPE (msg) != GST_MESSAGE_ELEMENT || structure == NULL)
     return FALSE;
 
-  return gst_structure_has_name (msg->structure, "missing-plugin");
+  return gst_structure_has_name (structure, "missing-plugin");
 }
 
 /* takes ownership of the description */
@@ -612,7 +615,7 @@ gst_installer_detail_new (gchar * description, const gchar * type,
   GString *s;
 
   s = g_string_new (GST_DETAIL_STRING_MARKER "|");
-  g_string_append_printf (s, "%u.%u|", GST_VERSION_MAJOR, GST_VERSION_MINOR);
+  g_string_append_printf (s, "%s|", GST_API_VERSION);
 
   progname = (const gchar *) g_get_prgname ();
   if (progname) {
@@ -642,7 +645,7 @@ gst_installer_detail_new (gchar * description, const gchar * type,
  * Returns an opaque string containing all the details about the missing
  * element to be passed to an external installer called via
  * gst_install_plugins_async() or gst_install_plugins_sync().
- * 
+ *
  * This function is mainly for applications that call external plugin
  * installation mechanisms using one of the two above-mentioned functions in
  * the case where the application knows exactly what kind of plugin it is
@@ -650,8 +653,6 @@ gst_installer_detail_new (gchar * description, const gchar * type,
  *
  * Returns: a newly-allocated detail string, or NULL on error. Free string
  *          with g_free() when not needed any longer.
- *
- * Since: 0.10.15
  */
 gchar *
 gst_missing_uri_source_installer_detail_new (const gchar * protocol)
@@ -672,7 +673,7 @@ gst_missing_uri_source_installer_detail_new (const gchar * protocol)
  * Returns an opaque string containing all the details about the missing
  * element to be passed to an external installer called via
  * gst_install_plugins_async() or gst_install_plugins_sync().
- * 
+ *
  * This function is mainly for applications that call external plugin
  * installation mechanisms using one of the two above-mentioned functions in
  * the case where the application knows exactly what kind of plugin it is
@@ -680,8 +681,6 @@ gst_missing_uri_source_installer_detail_new (const gchar * protocol)
  *
  * Returns: a newly-allocated detail string, or NULL on error. Free string
  *          with g_free() when not needed any longer.
- *
- * Since: 0.10.15
  */
 gchar *
 gst_missing_uri_sink_installer_detail_new (const gchar * protocol)
@@ -702,7 +701,7 @@ gst_missing_uri_sink_installer_detail_new (const gchar * protocol)
  * Returns an opaque string containing all the details about the missing
  * element to be passed to an external installer called via
  * gst_install_plugins_async() or gst_install_plugins_sync().
- * 
+ *
  * This function is mainly for applications that call external plugin
  * installation mechanisms using one of the two above-mentioned functions in
  * the case where the application knows exactly what kind of plugin it is
@@ -710,8 +709,6 @@ gst_missing_uri_sink_installer_detail_new (const gchar * protocol)
  *
  * Returns: a newly-allocated detail string, or NULL on error. Free string
  *          with g_free() when not needed any longer.
- *
- * Since: 0.10.15
  */
 gchar *
 gst_missing_element_installer_detail_new (const gchar * factory_name)
@@ -731,7 +728,7 @@ gst_missing_element_installer_detail_new (const gchar * factory_name)
  * Returns an opaque string containing all the details about the missing
  * element to be passed to an external installer called via
  * gst_install_plugins_async() or gst_install_plugins_sync().
- * 
+ *
  * This function is mainly for applications that call external plugin
  * installation mechanisms using one of the two above-mentioned functions in
  * the case where the application knows exactly what kind of plugin it is
@@ -739,8 +736,6 @@ gst_missing_element_installer_detail_new (const gchar * factory_name)
  *
  * Returns: a newly-allocated detail string, or NULL on error. Free string
  *          with g_free() when not needed any longer.
- *
- * Since: 0.10.15
  */
 gchar *
 gst_missing_decoder_installer_detail_new (const GstCaps * decode_caps)
@@ -771,7 +766,7 @@ gst_missing_decoder_installer_detail_new (const GstCaps * decode_caps)
  * Returns an opaque string containing all the details about the missing
  * element to be passed to an external installer called via
  * gst_install_plugins_async() or gst_install_plugins_sync().
- * 
+ *
  * This function is mainly for applications that call external plugin
  * installation mechanisms using one of the two above-mentioned functions in
  * the case where the application knows exactly what kind of plugin it is
@@ -779,8 +774,6 @@ gst_missing_decoder_installer_detail_new (const GstCaps * decode_caps)
  *
  * Returns: a newly-allocated detail string, or NULL on error. Free string
  *          with g_free() when not needed any longer.
- *
- * Since: 0.10.15
  */
 gchar *
 gst_missing_encoder_installer_detail_new (const GstCaps * encode_caps)
